[Scummvm-cvs-logs] SF.net SVN: scummvm:[47557] scummvm/trunk/engines/sci/engine/state.cpp

thebluegr at users.sourceforge.net thebluegr at users.sourceforge.net
Mon Jan 25 18:31:09 CET 2010


Revision: 47557
          http://scummvm.svn.sourceforge.net/scummvm/?rev=47557&view=rev
Author:   thebluegr
Date:     2010-01-25 17:30:59 +0000 (Mon, 25 Jan 2010)

Log Message:
-----------
Fixed kSetCursor semantics detection for KQ5 Amiga, by making a hack for KQ5 CD specific to that version only

Modified Paths:
--------------
    scummvm/trunk/engines/sci/engine/state.cpp

Modified: scummvm/trunk/engines/sci/engine/state.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/state.cpp	2010-01-25 17:21:55 UTC (rev 47556)
+++ scummvm/trunk/engines/sci/engine/state.cpp	2010-01-25 17:30:59 UTC (rev 47557)
@@ -234,9 +234,12 @@
 		break;
 	case kDetectSetCursorType:
 		objName = "Game";
-		// We need to check the overridden game object here. Fixes KQ5CD setCursor detection,
-		// as KQ5CD overrides the default setCursor selector of the Game object
-		objAddr = _gameObj;
+		objAddr = _segMan->findObjectByName(objName);
+		// KQ5CD overrides the default setCursor selector of the Game object,
+		// so we need to handle this separately
+		// KQ5 PC floppy is early SCI1, Amiga middle SCI1, and CD late SCI1
+		if (_gameId == "kq5" && getSciVersion() == SCI_VERSION_1_LATE)
+			objAddr = _gameObj;
 		slc = _kernel->_selectorCache.setCursor;
 		break;
 	case kDetectLofsType:


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list